##################################################################
##								##
##		   Graphiques et visualisation			##
##			de données avec R			##
##								##
##			      EXERCICE				##
##								##
##			Marina Doucerain			##
##		    marinadoucerain@gmail.com			##
##								##
##################################################################


# Charger le jeu de données 'Rgraphs_jeu de données.txt'

# Pour cet exercice, le but est d'examiner l'impact des différents types de programme d'enseignement du français sur les scores de performance en français des participants. 

# La variable 'prog' code les trois types d'intervention: 
# - control: pas de programme d'enseignement
# - instruction: enseignement classique avec emphase sur la grammaire et le vocabulaire
# - immersion: enseignement avec emphase sur l'expression orale et la communication

# Créer un diagramme à moustache montrant la distribution des scores post-test conditionnels au programme.

# Répéter le diagramme ci-dessus mais aussi conditionnels au sexe des participants. Identifier les observations aberrantes par leur statut de minorité visible ou non-visible.

# Les scores pre- et post-test sont-ils normalement distribués? Le vérifier en utilisant un diagramme quantile par quantile. Dans le premier, identifier automatiquement les 5 observations les plus aberrantes. Dans le deuxième, identifier les points aberrants manuellement.

# Illustrer la relation entre les scores pre- et post-test grâce à un nuage de point, conditionné par le statut minorité visible ou non-visible des participants. Identifier manuellement les observations les plus aberrantes.

# Créer une matrice de nuage de points illustrant la relation entre les scores pre- et post-test et le salaire final (salary.post). Faire en sorte que les observations de chaque programme d'enseignement s'affichent de différentes couleurs.

# Créer une variable diff pour la différence de score post-pretest. Régresser cette différence par rapport au programme, au statut de minorité et au sexe.

# Montrer la distribution densimétrique de la variable diff pour les différents programmes, en utilisant un graphique de type treillis. Créer un tel graphique avec lattice and avec ggplot2.

# Créer un diagramme à barre montrant la 'diff' moyenne pour chaque programme, avec un point superposé pour illustrer la moyenne. Ajouter un couche représentant les valeurs individuelles de diff (gràce à des points) pour chaque programme. 

# Régresser les scores 'diff' par rapport au programme, en contrôlant pour le sexe et le statut de minorité.

# Créer des graphiques diagnostiques pour voir si ce modèle est adéquat.

# Créer un petit jeu de données contenant les valeurs prédites par le modèle.

# Grâce à ggplot2, créer un graphique montrant les différences de scores prédites par le modèle pour les différents programmes d'intervention suivant le sexe des participants. Montrer les intervalles de confiance. Utiliser différentes couleurs pour les différents programmesd
# Personnaliser l'apparence de ce graphique. Ajouter des intitulés pour les axes, enlever la légende, changer la couleur des points, changer le thème.












###------------------------SOLUTIONS----------------------####

library(ggplot2)
library(lattice)
library(car)
library(ggthemes)

ss <- read.table("Rgraphs_jeu de données.txt")

boxplot(posttest ~ prog, data=ss)

Boxplot(posttest~prog+sex, data=ss, labels=as.character(ss$visible), cex.axis=.6)

qqPlot(ss$pretest, id.n=5, cex=.5, id.cex=.8)
qqPlot(ss$posttest, id.method="identify")

scatterplot(pretest~posttest | prog, data=ss, id.method="identify")

scatterplotMatrix(~pretest+posttest+salary.post, data=ss, groups=ss$prog)

ss$diff <- ss$posttest - ss$pretest

ggplot(data=ss, aes(x=diff, fill=prog, colour=prog)) + geom_density() +facet_grid(prog~.)+scale_fill_discrete(guide=F)+scale_colour_discrete(guide=F)

densityplot(~diff | prog, data=ss, layout=c(1,3), autokey=T, plot.points=F)

means <- data.frame(x=levels(ss$prog), y=tapply(ss$diff, ss$prog, mean))

ggplot(data=ss, aes(x=prog, y=diff))+ geom_bar(data=means, aes(x=x, y=y), stat="identity", width=.5, fill="grey80") + geom_jitter(aes(color=prog)) + geom_point(data=means, aes(x=x, y=y), size=8, colour="grey") 

mod <- lm(diff~prog + visible + sex, data=ss)

residualPlots(mod)
marginalModelPlots(mod)
avPlots(mod, id.method="identify")

influenceIndexPlot(mod, cex=.5, id.n=10, id.cex=.8)
influencePlot(mod, id.n=2, id.cex=.8)

pred <- expand.grid(prog=levels(ss$prog), visible=levels(ss$visible), sex=levels(ss$sex))
pred <- cbind(pred, predict(mod, newdata=pred, interval="confidence"))

pred$sex <- factor(pred$sex, labels=c("Femme", "Homme"))
p <- ggplot(data=subset(pred, visible=="no"), aes(x=prog, y=fit))
p + geom_errorbar(aes(ymin=lwr, ymax=upr, colour=prog), width=.2)+ geom_line(aes(group=1), colour="grey")+geom_point(aes(colour=prog), size=7) +  facet_grid(.~sex) + scale_y_continuous(name="Différence pre- post-test", limits=c(8,40)) + scale_x_discrete(name="Programme", breaks=levels(ss$prog), labels=c("Contrôle", "Immersion", "Instruction"))+scale_colour_brewer(guide=F, palette="Set2") +theme_bw()
	

	

